@@ -5,11 +5,11 @@
 extern "C" {
 #endif
 
-#define XMP_VERSION "4.3.10"
-#define XMP_VERCODE 0x04030a
+#define XMP_VERSION "4.3.11"
+#define XMP_VERCODE 0x04030b
 #define XMP_VER_MAJOR 4
 #define XMP_VER_MINOR 3
-#define XMP_VER_RELEASE 10
+#define XMP_VER_RELEASE 11
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
 # if defined(BUILDING_STATIC)
@@ -82,7 +82,7 @@ extern "C" {
 #define XMP_MAX_ENV_POINTS	32	/* Max number of envelope points */
 #define XMP_MAX_MOD_LENGTH	256	/* Max number of patterns in module */
 #define XMP_MAX_CHANNELS	64	/* Max number of channels in module */
-#define XMP_MAX_SRATE		49170	/* max sampling rate (Hz) */
+#define XMP_MAX_SRATE		192000	/* max sampling rate (Hz) */
 #define XMP_MIN_SRATE		4000	/* min sampling rate (Hz) */
 #define XMP_MIN_BPM		20	/* min BPM */
 /* frame rate = (50 * bpm / 125) Hz */
